# Linkedin_Queens_challenge
Solve the Linkedin daily challenge "Queens"

# Usage
Step 1- Take a snapshot of the daily queens problem board, and save this image

Step 2- Run the script `example.py` and specify the image path in it 